@@ -5,7 +5,7 @@ from contextvars import ContextVar
 from copy import copy
 
 from .selector import Element, MatchFunction, select
-from .selfless import Override, Selfless, choose, override
+from .selfless import Override, Selfless, choose, name_error, override
 from .tags import match_tag
 from .utils import (
     ABSENT,
@@ -274,6 +274,8 @@ class SetterAccumulator(ImmediateAccumulator):
 
 class GetterAccumulator(ImmediateAccumulator):
     def varget(self, element, varname, category):
+        if not check_element(element, varname, category):
+            return ABSENT
         cap = Capture(element)
         self.captures[element.capture] = cap
         cap.names.append(varname)
@@ -441,12 +443,12 @@ def interact(sym, key, category, __self__, value):
         if sym not in fr.accumulators:
             if from_state is ABSENT and not isinstance(value, Override):
                 if value is ABSENT:
-                    raise NameError(f"Variable {sym} of {__self__} is not set.")
+                    raise name_error(sym, __self__)
                 return value
             elif value is ABSENT and not isinstance(from_state, Override):
                 return from_state
             else:
-                return choose([value, from_state])
+                return choose([value, from_state], name=sym)
 
         if sym in fr.getters:
             fr_value = fr.get(sym, key, category)
@@ -465,7 +467,7 @@ def interact(sym, key, category, __self__, value):
         ):
             pass
         else:
-            value = choose([value, fr_value, from_state])
+            value = choose([value, fr_value, from_state], name=sym)
         if value is ABSENT:
             raise NameError(f"Variable {sym} of {__self__} is not set.")
 
